import sys
from io import StringIO

class CapturingStdOut(list):
    """
    Class to capture output of function.
    Usage:

        with Capturing(output) as output:  # note the constructor argument
            print('hello world2')

        print('output:', output)
    """
    def __enter__(self):
        self._stdout = sys.stdout
        sys.stdout = self._stringio = StringIO()
        return self
    def __exit__(self, *args):
        self.extend(self._stringio.getvalue().splitlines())
        del self._stringio    # free up some memory
        sys.stdout = self._stdout

class CapturingStdErr(list):
    """
    Class to capture output of function.
    Usage:

        with Capturing(output) as output:  # note the constructor argument
            print('hello world2')

        print('output:', output)
    """
    def __enter__(self):
        self._stderr = sys.stderr
        sys.stderr = self._stringio = StringIO()
        return self
    def __exit__(self, *args):
        self.extend(self._stringio.getvalue().splitlines())
        del self._stringio    # free up some memory
        sys.stderr = self._stderr
