import math
from pathlib import Path
import re

units = {"B": 1, "KB": 10 ** 3, "MB": 10 ** 6, "GB": 10 ** 9, "TB": 10 ** 12}


def file_size(file_path):
    return Path(file_path).stat().st_size


def file_list_size(file_list):
    return sum([file_size(fp) for fp in file_list])


def convert_size(size_bytes):
    if size_bytes == 0:
        return "0B"
    size_name = ("B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
    i = int(math.floor(math.log(size_bytes, 1024)))
    p = math.pow(1024, i)
    s = round(size_bytes / p, 2)
    return "%s %s" % (s, size_name[i])


def parse_size(size):
    pattern = "([0-9\.]+) *([BKMGT]+)"
    # pattern = "([0-9\.])"
    m = re.search(pattern, size)
    if m:
        number = float(m.group(1))
        unit = m.group(2)
    else:
        raise AssertionError(f"Can't parse:{size}")
    return int(float(number) * units[unit])
